@@ -18,6 +18,7 @@
 #include "../src/common.h"
 #include "../src/util.h"
 #include "../src/priv.h"
+#include "zend_exceptions.h"
 
 /* {{{ Private */
 
@@ -186,6 +187,20 @@ PHP_METHOD(EventHttpConnection, __construct)
 }
 /* }}} */
 
+/*{{{ proto int EventHttpConnection::__sleep */
+PHP_METHOD(EventHttpConnection, __sleep)
+{
+	zend_throw_exception_ex(php_event_get_exception(), 0, "EventHttpConnection instances are not serializable");
+}
+/*}}}*/
+
+/*{{{ proto int EventHttpConnection::__wakeup */
+PHP_METHOD(EventHttpConnection, __wakeup)
+{
+	zend_throw_exception_ex(php_event_get_exception(), 0, "EventHttpConnection instances are not serializable");
+}
+/*}}}*/
+
 /* {{{ proto EventBase EventHttpConnection::getBase(void);
  *
  * Get event base associated with the http connection.
